@@ -149,16 +149,16 @@ class TestMovingToLondonScenario(unittest.TestCase):
         answer = "This box"
         ####
         res = self.dialog.test('ACHILLE', stmt, answer)
-        self.assertEquals(res[1][1],"The Lords of the robots.")
+        self.assertEqual(res[1][1],"The Lords of the robots.")
         
         self.oro.removeForAgent('ACHILLE',['ACHILLE pointsAt CARDBOARD_BOX'])
         
         stmt = "Ok. And where is the other tape?"
         ####
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1],"The other tape is on the table.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1],"The other tape is on the table.")
         
         stmt = "Ok. Thanks."
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1],"You're welcome.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1],"You're welcome.")
         
         """Julie arrives, and gives two big boxes to ACHILLE. He can not take anything!"""
        
@@ -182,7 +182,7 @@ class TestMovingToLondonScenario(unittest.TestCase):
         stmt = "And now, can you reach this tape?"
         ####
         ### Check ['myself reaches TAPE2']
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1],"I don't know, if I can reach this tape now.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1],"I don't know, if I can reach this tape now.")
         self.oro.removeForAgent('ACHILLE',['ACHILLE pointsAt TAPE2'])
         
         """Julie pushes again the tape. It is now reachable.
