@@ -12,7 +12,7 @@ from dialogs.sentence import *
 from dialogs.parsing import preprocessing
 from dialogs.parsing import analyse_sentence
 from dialogs.parsing import parser
-from anaphora_matching import *
+from .anaphora_matching import *
 from dialogs.parsing.parser_test import compare_nominal_group
 
 
@@ -32,15 +32,15 @@ print(utterance)
 print('#################################################################')
 print('')
 sentences=[Sentence('statement', '', 
-        [Nominal_Group(['the'],['bottle'],['blue'],[Nominal_Group([],['Jido'],[],[],[])],[])], 
-        [Verbal_Group(['be'], [],'present simple', 
+        [NominalGroup(['the'],['bottle'],['blue'],[NominalGroup([],['Jido'],[],[],[])],[])],
+        [VerbalGroup(['be'], [],'present simple',
             [], 
-            [Indirect_Complement(['on'],[Nominal_Group(['the'],['table'],[],[],[])])],
+            [IndirectComplement(['on'],[NominalGroup(['the'],['table'],[],[],[])])],
             [], [] ,'affirmative',[])]),
     Sentence('statement', '', 
-        [Nominal_Group([],['I'],[],[],[])], 
-        [Verbal_Group(['play'], [],'future simple', 
-            [Nominal_Group(['a'],['guitar'],[],[],[]),Nominal_Group(['a'],['piano'],[],[],[]),Nominal_Group(['a'],['violon'],[],[],[])], 
+        [NominalGroup([],['I'],[],[],[])],
+        [VerbalGroup(['play'], [],'future simple',
+            [NominalGroup(['a'],['guitar'],[],[],[]),NominalGroup(['a'],['piano'],[],[],[]),NominalGroup(['a'],['violon'],[],[],[])],
             [],
             [], [] ,'affirmative',[])])]
     
@@ -63,15 +63,15 @@ print(utterance)
 print('#################################################################')
 print('')
 sentences=[Sentence('statement', '', 
-        [Nominal_Group(['the'],['bottle'],['blue'],[Nominal_Group([],['Jido'],[],[],[])],[])], 
-        [Verbal_Group(['be'], [],'present simple', 
+        [NominalGroup(['the'],['bottle'],['blue'],[NominalGroup([],['Jido'],[],[],[])],[])],
+        [VerbalGroup(['be'], [],'present simple',
             [], 
-            [Indirect_Complement(['on'],[Nominal_Group(['the'],['table'],[],[],[])])],
+            [IndirectComplement(['on'],[NominalGroup(['the'],['table'],[],[],[])])],
             [], [] ,'affirmative',[])]),
     Sentence('statement', '', 
-        [Nominal_Group([],['I'],[],[],[])], 
-        [Verbal_Group(['play'], [],'future simple', 
-            [Nominal_Group(['a'],['guitar'],[],[],[]),Nominal_Group(['a'],['piano'],[],[],[]),Nominal_Group(['a'],['violon'],[],[],[])], 
+        [NominalGroup([],['I'],[],[],[])],
+        [VerbalGroup(['play'], [],'future simple',
+            [NominalGroup(['a'],['guitar'],[],[],[]),NominalGroup(['a'],['piano'],[],[],[]),NominalGroup(['a'],['violon'],[],[],[])],
             [],
             [], [] ,'affirmative',[])])]
 
@@ -95,22 +95,22 @@ print('###############################################################')
 print('')
 
 sentences = [Sentence('statement', '',
-                      [Nominal_Group([], ['it'], [], [], [])],
-                      [Verbal_Group(['be'], [], 'present simple',
+                      [NominalGroup([], ['it'], [], [], [])],
+                      [VerbalGroup(['be'], [], 'present simple',
                           [],
-                                    [Indirect_Complement(['on'], [Nominal_Group(['the'], ['table'], [], [], [])])],
+                                    [IndirectComplement(['on'], [NominalGroup(['the'], ['table'], [], [], [])])],
                           [], [], 'affirmative', [])]),
              Sentence('imperative', '',
                  [],
-                      [Verbal_Group(['give'], [], 'present simple',
-                                    [Nominal_Group(['the'], ['bottle'], [], [], [])],
-                                    [Indirect_Complement([], [Nominal_Group([], ['me'], [], [], [])])],
+                      [VerbalGroup(['give'], [], 'present simple',
+                                    [NominalGroup(['the'], ['bottle'], [], [], [])],
+                                    [IndirectComplement([], [NominalGroup([], ['me'], [], [], [])])],
                           [], [], 'affirmative', [])]),
              Sentence('statement', '',
-                      [Nominal_Group([], ['I'], [], [], [])],
-                      [Verbal_Group(['give'], [], 'present simple',
-                                    [Nominal_Group(['the'], ['shelf'], [], [], [])],
-                                    [Indirect_Complement(['to'], [Nominal_Group([], ['you'], [], [], [])])],
+                      [NominalGroup([], ['I'], [], [], [])],
+                      [VerbalGroup(['give'], [], 'present simple',
+                                    [NominalGroup(['the'], ['shelf'], [], [], [])],
+                                    [IndirectComplement(['to'], [NominalGroup([], ['you'], [], [], [])])],
                           [], [], 'negative', [])])]
 
 sentences[0].sn[0].id = 'azeaz'
@@ -143,19 +143,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group([], ['it'], [], [], [])
+        nominal_group_struc = NominalGroup([], ['it'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "no. I mean the shelf."
@@ -172,9 +172,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['shelf'], [], [], [])
+        result = NominalGroup(['the'], ['shelf'], [], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_02(self):
         """
@@ -197,19 +197,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group([], ['it'], [], [], [])
+        nominal_group_struc = NominalGroup([], ['it'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "no."
@@ -226,9 +226,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['bottle'], [], [], [])
+        result = NominalGroup(['the'], ['bottle'], [], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_03(self):
         """
@@ -251,19 +251,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group([], ['it'], [], [], [])
+        nominal_group_struc = NominalGroup([], ['it'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "no. I mean the blue bottle."
@@ -280,9 +280,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['bottle'], [['blue', []]], [], [])
+        result = NominalGroup(['the'], ['bottle'], [['blue', []]], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_04(self):
         """
@@ -305,19 +305,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group([], ['it'], [], [], [])
+        nominal_group_struc = NominalGroup([], ['it'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "yes"
@@ -334,9 +334,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_05(self):
         """
@@ -359,19 +359,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group(['this'], ['one'], [], [], [])
+        nominal_group_struc = NominalGroup(['this'], ['one'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "yes"
@@ -388,9 +388,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_06(self):
         """
@@ -413,19 +413,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group(['this'], ['one'], [], [], [])
+        nominal_group_struc = NominalGroup(['this'], ['one'], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "no. I mean the blue bottle."
@@ -442,9 +442,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['bottle'], [['blue', []]], [], [])
+        result = NominalGroup(['the'], ['bottle'], [['blue', []]], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_07(self):
         """
@@ -467,19 +467,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group(['this'], [], [], [], [])
+        nominal_group_struc = NominalGroup(['this'], [], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "yes"
@@ -496,9 +496,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
     def test_08(self):
         """
@@ -521,19 +521,19 @@ class TestAnaphora(unittest.TestCase):
         print('#####################################')
         print('')
         print('the nominal group that we have to change')
-        nominal_group_struc = Nominal_Group(['this'], [], [], [], [])
+        nominal_group_struc = NominalGroup(['this'], [], [], [], [])
         print((str(nominal_group_struc)))
 
         print('#####################################')
         print('After the first replacement')
         gr = first_replacement(list_gr, nominal_group_struc)
-        print("the id of the nominal group: ", gr.id)
+        print(("the id of the nominal group: ", gr.id))
         print((str(gr)))
         print('')
 
-        result = Nominal_Group(['the'], ['table'], [], [], [])
+        result = NominalGroup(['the'], ['table'], [], [], [])
         result_test = compare_nominal_group([gr], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
         print('#####################################')
         utterance = "no. I mean the blue bottle."
@@ -550,9 +550,9 @@ class TestAnaphora(unittest.TestCase):
         print('the flag')
         print((str(nominal_group_struc[1])))
 
-        result = Nominal_Group(['the'], ['bottle'], [['blue', []]], [], [])
+        result = NominalGroup(['the'], ['bottle'], [['blue', []]], [], [])
         result_test = compare_nominal_group([nominal_group_struc[0]], [result])
-        self.assertEquals(result_test, 0)
+        self.assertEqual(result_test, 0)
 
 
 def test_suite():
