@@ -174,7 +174,7 @@ class ContentAnalyser(object):
 
                         vrb_main = verb.lstrip('can+')
 
-                        if not vrb_main in ResourcePool().state + ResourcePool().action_verb_with_passive_behaviour.keys() + ResourcePool().goal_verbs:
+                        if not vrb_main in ResourcePool().state + list(ResourcePool().action_verb_with_passive_behaviour.keys()) + ResourcePool().goal_verbs:
                             logger.debug(colored_print(
                                 "Interpreting the <can + action verb> sequence as a desire.\nApplying transformation:",
                                 "magenta"))
