@@ -9,7 +9,7 @@ logger = logging.getLogger('dialogs')
 
 from dialogs.resources_manager import ResourcePool
 from dialogs.dialog_core import Dialog
-from discrimination import Discrimination
+from .discrimination import Discrimination
 from dialogs.verbalization.verbalization import Verbalizer
 from dialogs.dialog_exceptions import *
 
@@ -50,13 +50,13 @@ class TestDiscrimination(unittest.TestCase):
                                                 'SPACENAVBOX isOn ACCESSKIT'
             ])
 
-            ResourcePool().ontology_server.addForAgent("raquel",
+            ResourcePool().ontology_server.addForAgent(ResourcePool().get_model_mapping("raquel"),
                                                        ["BLUE_BOTTLE isVisible true",
                                                         "ORANGE_BOTTLE isVisible true"
                                                        ])
 
         except AttributeError: #the ontology server is not started of doesn't know the method
-            raise (DialogError("The ontology server is not started!"))
+            raise DialogError
 
     def test_01(self):
         logger.info("Test1: No ambiguity.")
@@ -68,7 +68,7 @@ class TestDiscrimination(unittest.TestCase):
         except UnsufficientInputError:
             self.fail("Should need any more info")
 
-        self.assertEquals(expected_result, res)
+        self.assertEqual(expected_result, res)
 
     def test_02(self):
         logger.info("\nTest2: Complete self.discriminant in robot model found.")
@@ -76,10 +76,10 @@ class TestDiscrimination(unittest.TestCase):
         expected_result = "Which color is the bottle? Blue or orange or yellow."
 
         try:
-            res = self.disc.clarify(description)
+            self.disc.clarify(description)
         except UnsufficientInputError as use:
-            self.assertEquals(use.value['status'], 'SUCCESS')
-            self.assertEquals(self.verbalizer.verbalize(use.value['question']), expected_result)
+            self.assertEqual(use.value['status'], 'SUCCESS')
+            self.assertEqual(self.verbalizer.verbalize(use.value['question']), expected_result)
             return
 
         self.fail("Should trigger an unsufficient input exception!")
@@ -93,7 +93,7 @@ class TestDiscrimination(unittest.TestCase):
         try:
             res = self.disc.clarify(description)
         except UnsufficientInputError as use:
-            self.assertEquals(use.value['status'], 'SUCCESS')
+            self.assertEqual(use.value['status'], 'SUCCESS')
             self.assertIn(self.verbalizer.verbalize(use.value['question']), expected_result)
             return
 
@@ -107,8 +107,8 @@ class TestDiscrimination(unittest.TestCase):
         try:
             res = self.disc.clarify(description)
         except UnsufficientInputError as use:
-            self.assertEquals(use.value['status'], 'SUCCESS')
-            self.assertEquals(self.verbalizer.verbalize(use.value['question']), expected_result)
+            self.assertEqual(use.value['status'], 'SUCCESS')
+            self.assertEqual(self.verbalizer.verbalize(use.value['question']), expected_result)
             return
 
         self.fail("Should trigger an unsufficient input exception!")
@@ -121,8 +121,8 @@ class TestDiscrimination(unittest.TestCase):
         try:
             res = self.disc.clarify(description)
         except UnsufficientInputError as use:
-            self.assertEquals(use.value['status'], 'SUCCESS')
-            self.assertEquals(self.verbalizer.verbalize(use.value['question']), expected_result)
+            self.assertEqual(use.value['status'], 'SUCCESS')
+            self.assertEqual(self.verbalizer.verbalize(use.value['question']), expected_result)
             return
 
         self.fail("Should trigger an unsufficient input exception!")
@@ -140,7 +140,7 @@ class TestDescriptionGeneration(TestDiscrimination):
 
         logger.info("Result of desc generation: " + str(res))
 
-        self.assertEquals(res[0], expected_result[0])
+        self.assertEqual(res[0], expected_result[0])
         self.assertTrue(check_results(res[1], expected_result[1], allow_question_mark=True))
 
 
@@ -152,7 +152,7 @@ class TestDescriptionGeneration(TestDiscrimination):
 
         logger.info("Result of desc generation: " + str(res))
 
-        self.assertEquals(res[0], expected_result[0])
+        self.assertEqual(res[0], expected_result[0])
         self.assertTrue(check_results(res[1], expected_result[1], allow_question_mark=True))
 
 
@@ -164,7 +164,7 @@ class TestDescriptionGeneration(TestDiscrimination):
 
         logger.info("Result of desc generation: " + str(res))
 
-        self.assertEquals(res[0], expected_result[0])
+        self.assertEqual(res[0], expected_result[0])
         self.assertTrue(check_results(res[1], expected_result[1], allow_question_mark=True))
 
 
