@@ -79,23 +79,17 @@ class QuestionHandler(object):
                         [agent, object] = s.split(" knows ")
 
                         onto_lookup = []
-                        try:
-                            logger.debug(level_marker(level=2,
-                                                      color="yellow") + "Looking up for " + object + " in " + agent + "'s model")
-                            onto_lookup = ResourcePool().ontology_server.lookupForAgent(agent, object)
-                        except AttributeError:
-                            pass
+                        logger.debug(level_marker(level=2,
+                                                    color="yellow") + "Looking up for " + object + " in " + agent + "'s model")
+                        onto_lookup = ResourcePool().ontology_server.lookupForAgent(ResourcePool().get_model_mapping(agent), object)
 
                         self._answer = self._answer and (True if onto_lookup else False)
 
                 self.process_on_knowing_concept = False
             else:
-                try:
-                    logger.debug(level_marker(level=2, color="yellow") + "Checking in the ontology: " + colored_print(
-                        str(self._statements), None, "magenta"))
-                    self._answer = ResourcePool().ontology_server.check(self._statements)
-                except AttributeError: #the ontology server is not started of doesn't know the method
-                    pass
+                logger.debug(level_marker(level=2, color="yellow") + "Checking in the ontology: " + colored_print(
+                    str(self._statements), None, "magenta"))
+                self._answer = ResourcePool().ontology_server.check(self._statements)
 
         #Case the question is a w_question : find the concept the concept that answers the question
         if sentence.data_type == W_QUESTION:
@@ -138,7 +132,7 @@ class QuestionHandler(object):
 
                         prepositions_list = ResourcePool().preposition_rdf_object_property.copy()
                         roles = dict([(preposition, prepositions_list[preposition][0]) \
-                                      for preposition in prepositions_list.keys() \
+                                      for preposition in list(prepositions_list.keys()) \
                                       if 'objectFoundInLocation' in prepositions_list[preposition]])
 
                         #Case of ojectFound in location
@@ -149,13 +143,11 @@ class QuestionHandler(object):
                                 continue
 
                             stmts = [s.replace('objectFoundInLocation', roles[role]) for s in statements]
-                            try:
-                                logger.debug(level_marker(level=2,
-                                                          color="yellow") + "Searching in " + agent + " model: " + colored_print(
-                                    str(stmts), None, "magenta"))
-                                answers = ResourcePool().ontology_server.findForAgent(agent, '?concept', stmts)
-                            except AttributeError: #the ontology server is not started of doesn't know the method
-                                pass
+
+                            logger.debug(level_marker(level=2,
+                                                        color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                                str(stmts), None, "magenta"))
+                            answers = ResourcePool().ontology_server.findForAgent(ResourcePool().get_model_mapping(agent), '?concept', stmts)
 
                             prepositions_already_used.append(roles[role])
 
@@ -166,28 +158,22 @@ class QuestionHandler(object):
                         #Case of object found in location + direction
                         stmts = [s.replace('objectFoundInLocation', 'isAt') for s in statements]
                         for role in ResourcePool().direction_words:
-                            try:
-                                logger.debug(level_marker(level=2,
-                                                          color="yellow") + "Searching in " + agent + " model: " + colored_print(
-                                    str(stmts + ['?concept is' + role.capitalize() + 'Of ?obj',
-                                                 '?concept rdf:type Location']), None, "magenta"))
-                                answers = ResourcePool().ontology_server.findForAgent(agent, '?obj', stmts + [
-                                    '?concept is' + role.capitalize() + 'Of ?obj', '?concept rdf:type Location'])
-                            except AttributeError: #the ontology server is not started of doesn't know the method
-                                pass
+                            logger.debug(level_marker(level=2,
+                                                        color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                                str(stmts + ['?concept is' + role.capitalize() + 'Of ?obj',
+                                                '?concept rdf:type Location']), None, "magenta"))
+                            answers = ResourcePool().ontology_server.findForAgent(ResourcePool().get_model_mapping(agent), '?obj', stmts + [
+                                '?concept is' + role.capitalize() + 'Of ?obj', '?concept rdf:type Location'])
 
                             if answers:
                                 ResourcePool().mark_active(answers)
                                 self._answer.append([[role], answers])
 
                     else:
-                        try:
-                            logger.debug(level_marker(level=2,
-                                                      color="yellow") + "Searching in " + agent + " model: " + colored_print(
-                                str(statements), None, "magenta"))
-                            answers = ResourcePool().ontology_server.findForAgent(agent, '?concept', statements)
-                        except AttributeError: #the ontology server is not started of doesn't know the method
-                            pass
+                        logger.debug(level_marker(level=2,
+                                                    color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                            str(statements), None, "magenta"))
+                        answers = ResourcePool().ontology_server.findForAgent(ResourcePool().get_model_mapping(agent), '?concept', statements)
 
                         if answers:
                             ResourcePool().mark_active(answers)
@@ -226,10 +212,7 @@ class QuestionHandler(object):
                 break
 
         if find_id:
-            try:
-                sit_id = ResourcePool().ontology_server.find(['?event'], statements)
-            except AttributeError: #the ontology server is not started of doesn't know the method
-                pass
+            sit_id = ResourcePool().ontology_server.find(['?event'], statements)
 
             if sit_id:
                 logger.debug(
@@ -278,7 +261,7 @@ class QuestionHandler(object):
                     if verb.lower() in ResourcePool().state:
                         stmts.append(sn.id + ' ' + role + ' ?concept')
                     # Case of action verb with a passive behaviour
-                    elif verb.lower() in ResourcePool().action_verb_with_passive_behaviour.keys():
+                    elif verb.lower() in list(ResourcePool().action_verb_with_passive_behaviour.keys()):
                         stmts.append(
                             sn.id + ' ' + ResourcePool().action_verb_with_passive_behaviour[verb.lower()] + ' ?concept')
 
@@ -360,12 +343,9 @@ class QuestionHandler(object):
                 self._sentence.aim = "thing"
 
         #Concept's Type
-        elif not self._sentence.aim in QuestionAimDict().dic_aim.keys():
+        elif not self._sentence.aim in list(QuestionAimDict().dic_aim.keys()):
             logger.debug("\tFound the aim: " + aim + ".Extending statements with [?concept rdf:type aim]")
-            try:
-                onto = ResourcePool().ontology_server.lookupForAgent(agent, aim)
-            except AttributeError:
-                onto = None
+            onto = ResourcePool().ontology_server.lookupForAgent(ResourcePool().get_model_mapping(agent), aim)
 
             concept_descriptor = ["?concept rdf:type " + get_class_name(aim, onto)]
             self._sentence.aim = "thing"
@@ -454,12 +434,12 @@ class QuestionAimDict(object):
         #Dictionaries related to thematice roles verbs
         verbs_dic = ResourcePool().thematic_roles.verbs
         self.dic_on_direct_obj = dict(
-            [(verb, role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[0:1]])
+            [(verb, role.id) for verb in list(verbs_dic.keys()) for role in verbs_dic[verb].roles[0:1]])
         self.dic_on_direct_obj[None] = 'involves'
         self.dic_on_direct_obj['be'] = 'owl:sameAs'
 
         self.dic_on_indirect_obj = dict(
-            [(verb, role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[1:2]])
+            [(verb, role.id) for verb in list(verbs_dic.keys()) for role in verbs_dic[verb].roles[1:2]])
         self.dic_on_indirect_obj['be'] = None
         self.dic_on_indirect_obj[None] = 'owl:sameAs'
 
