@@ -45,7 +45,7 @@ class TestQuestionHandler(unittest.TestCase):
                                             'take_my_cube involves another_cube',
                                             'take_my_cube rdf:type Take',
 
-                                            'SPEAKER pointsAt another_cube',
+                                            'SPEAKER focusesOn another_cube',
 
                                             'id_danny rdfs:label "Danny"',
 
@@ -56,8 +56,8 @@ class TestQuestionHandler(unittest.TestCase):
 
                                             'id_danny sees SPEAKER',
         ])
-        ResourcePool().ontology_server.addForAgent('SPEAKER',
-                                                   [
+        ResourcePool().ontology_server.addForAgent(ResourcePool().get_model_mapping('SPEAKER'),
+                                                   [   'SPEAKER rdf:type Human',
                                                        'SPEAKER rdfs:label "Patrick"',
                                                        'blue_cube rdf:type Cube',
                                                        'blue_cube hasColor blue',
@@ -81,7 +81,7 @@ class TestQuestionHandler(unittest.TestCase):
                                                        'take_my_cube involves another_cube',
                                                        'take_my_cube rdf:type Take',
 
-                                                       'SPEAKER pointsAt another_cube',
+                                                       'SPEAKER focusesOn another_cube',
 
                                                        'id_danny rdfs:label "Danny"',
 
@@ -100,19 +100,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_1_where_question ******************")
         logger.info("Where is the blue cube?")
         sentence = Sentence(W_QUESTION, "place",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['cube'],
                                            [['blue', []]],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present_simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'table1'
         self.process(sentence, expected_result)
@@ -121,19 +121,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_2_where_question ******************")
         logger.info("Where is the small cube?")
         sentence = Sentence(W_QUESTION, "place",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['cube'],
                                            [['small', []]],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present_simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'shelf1'
 
@@ -144,19 +144,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_3_what_question ******************")
         logger.info("What do you see?")
         sentence = Sentence(W_QUESTION, "thing",
-                            [Nominal_Group([],
+                            [NominalGroup([],
                                 ['you'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['see'],
+                            [VerbalGroup(['see'],
                                 [],
                                           'present_simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'shelf1'
 
@@ -167,10 +167,10 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("what is blue?")
         sentence = Sentence(W_QUESTION, "thing",
             [],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
-                                          [Nominal_Group([],
+                                          [NominalGroup([],
                                               [],
                                               [['blue', []]],
                                               [],
@@ -178,7 +178,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'blue_cube'
         self.process(sentence, expected_result)
@@ -187,19 +187,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_9_what_question_this ******************")
         logger.info("what is this?")
         sentence = Sentence(W_QUESTION, "thing",
-                            [Nominal_Group(['this'],
+                            [NominalGroup(['this'],
                                 [],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'another_cube'
         self.process(sentence, expected_result)
@@ -209,10 +209,10 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("what object is blue?")
         sentence = Sentence(W_QUESTION, "object",
             [],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
-                                          [Nominal_Group([],
+                                          [NominalGroup([],
                                               [],
                                               [['blue', []]],
                                               [],
@@ -220,7 +220,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'blue_cube'
         self.process(sentence, expected_result)
@@ -229,19 +229,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_11_w_question ******************")
         logger.info("what size is this?")
         sentence = Sentence(W_QUESTION, "size",
-                            [Nominal_Group(['this'],
+                            [NominalGroup(['this'],
                                 [],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'small'
         self.process(sentence, expected_result)
@@ -250,19 +250,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_12_what_question ******************")
         logger.info("what color is the blue_cube?")
         sentence = Sentence(W_QUESTION, "color",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['blue_cube'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'blue'
         self.process(sentence, expected_result)
@@ -271,19 +271,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_13_who_question ******************")
         logger.info("who is the SPEAKER?")
         sentence = Sentence(W_QUESTION, "people",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['SPEAKER'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'SPEAKER'
         self.process(sentence, expected_result)
@@ -293,10 +293,10 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("who sees Patrick?")
         sentence = Sentence(W_QUESTION, "people",
             [],
-                            [Verbal_Group(['see'],
+                            [VerbalGroup(['see'],
                                 [],
                                           'present simple',
-                                          [Nominal_Group([],
+                                          [NominalGroup([],
                                               ['Patrick'],
                                               [],
                                               [],
@@ -304,7 +304,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'id_danny'
 
@@ -315,15 +315,15 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_15_who_question ******************")
         logger.info("who does Danny give the small cube?")
         sentence = Sentence(W_QUESTION, "people",
-                            [Nominal_Group([],
+                            [NominalGroup([],
                                 ['Danny'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['give'],
+                            [VerbalGroup(['give'],
                                 [],
                                           'present simple',
-                                          [Nominal_Group(['the'],
+                                          [NominalGroup(['the'],
                                                          ['cube'],
                                                          [['small', []]],
                                               [],
@@ -331,7 +331,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = 'SPEAKER'
         self.process(sentence, expected_result)
@@ -341,15 +341,15 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_4_y_n_question action verb******************")
         logger.info("Did you get the blue cube?")
         sentence = Sentence(YES_NO_QUESTION, "",
-                            [Nominal_Group([],
+                            [NominalGroup([],
                                 ['you'],
                                 [''],
                                 [],
                                 [])],
-                            [Verbal_Group(['get'],
+                            [VerbalGroup(['get'],
                                 [],
                                           'past simple',
-                                          [Nominal_Group(['the'],
+                                          [NominalGroup(['the'],
                                                          ['cube'],
                                                          [['blue', []]],
                                               [],
@@ -357,7 +357,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = True
         self.process(sentence, expected_result)
@@ -367,24 +367,24 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_5_y_n_question verb to be followed by complement******************")
         logger.info("Is the blue cube on the table1?")
         sentence = Sentence(YES_NO_QUESTION, "",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['cube'],
                                            [['blue', []]],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
-                                          [Indirect_Complement(['on'],
-                                                               [Nominal_Group(['the'],
+                                          [IndirectComplement(['on'],
+                                                               [NominalGroup(['the'],
                                                                               ['table1'],
                                                                    [],
                                                                    [],
                                                                    [])])],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = True
         self.process(sentence, expected_result)
@@ -394,15 +394,15 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_6_y_n_question ******************")
         logger.info("Is the small cube blue?")
         sentence = Sentence(YES_NO_QUESTION, "",
-                            [Nominal_Group(['the'],
+                            [NominalGroup(['the'],
                                            ['cube'],
                                            [['small', []]],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
-                                          [Nominal_Group([],
+                                          [NominalGroup([],
                                               [],
                                               [['blue', []]],
                                               [],
@@ -410,7 +410,7 @@ class TestQuestionHandler(unittest.TestCase):
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = False
         self.process(sentence, expected_result)
@@ -420,24 +420,24 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_7_y_n_question verb to be ******************")
         logger.info("Is my cube on the table1?")
         sentence = Sentence(YES_NO_QUESTION, "",
-                            [Nominal_Group(['my'],
+                            [NominalGroup(['my'],
                                            ['cube'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
-                                          [Indirect_Complement(['on'],
-                                                               [Nominal_Group(['the'],
+                                          [IndirectComplement(['on'],
+                                                               [NominalGroup(['the'],
                                                                               ['table1'],
                                                                    [],
                                                                    [],
                                                                    [])])],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = False
         self.process(sentence, expected_result)
@@ -446,19 +446,19 @@ class TestQuestionHandler(unittest.TestCase):
         logger.info("\n*************  test_9_how_question ******************")
         logger.info("How is my car?")
         sentence = Sentence(W_QUESTION, "manner",
-                            [Nominal_Group(['my'],
+                            [NominalGroup(['my'],
                                            ['cube'],
                                 [],
                                 [],
                                 [])],
-                            [Verbal_Group(['be'],
+                            [VerbalGroup(['be'],
                                 [],
                                           'present simple',
                                 [],
                                 [],
                                 [],
                                 [],
-                                          Verbal_Group.affirmative,
+                                          VerbalGroup.affirmative,
                                 [])])
         expected_result = [['blue', []]]
         self.process(sentence, expected_result)
@@ -485,7 +485,7 @@ class TestQuestionHandler(unittest.TestCase):
             # res may be a list of several IDs that match the question. Here the result succeed if the expected one is among them
 
         if sentence.data_type == YES_NO_QUESTION:
-            self.assertEquals(expected_result, res)
+            self.assertEqual(expected_result, res[0])
 
 
 class TestQuestionHandlerDialog(unittest.TestCase):
@@ -569,7 +569,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "The yellow banana.")
+        self.assertEqual(res[1][1], "The yellow banana.")
 
     def test_question3_what(self):
         logger.info("\n##################### test_question3_what ########################\n")
@@ -579,7 +579,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "The yellow banana.")
+        self.assertEqual(res[1][1], "The yellow banana.")
 
 
     def test_question4_what(self):
@@ -600,7 +600,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "This is the yellow banana.")
+        self.assertEqual(res[1][1], "This is the yellow banana.")
 
 
     def test_question6_who(self):
@@ -613,7 +613,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "I am Jido.")
+        self.assertEqual(res[1][1], "I am Jido.")
 
     def test_question6_who(self):
 
@@ -625,7 +625,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "My name is Jido.")
+        self.assertEqual(res[1][1], "My name is Jido.")
 
 
     def test_question7_who(self):
@@ -644,7 +644,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
         stmt = "Who do you see?"
 
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "I see Tom.")
+        self.assertEqual(res[1][1], "I see Tom.")
 
     def test_question8_what(self):
         logger.info("\n##################### test_question8_what ########################\n")
@@ -661,7 +661,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "Tom is Tom.")
+        self.assertEqual(res[1][1], "Tom is Tom.")
 
 
     def test_question10(self):
@@ -672,7 +672,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "Yes. I see the yellow banana.")
+        self.assertEqual(res[1][1], "Yes. I see the yellow banana.")
 
     def test_question11(self):
         logger.info("\n##################### test_question11 ########################\n")
@@ -682,7 +682,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "Yes. The yellow banana is on the shelf.")
+        self.assertEqual(res[1][1], "Yes. The yellow banana is on the shelf.")
 
     def test_question12(self):
         logger.info("\n##################### Check label ########################\n")
@@ -692,7 +692,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "I see Tom.")
+        self.assertEqual(res[1][1], "I see Tom.")
 
     def test_question13(self):
         logger.info("\n##################### Check label ########################\n")
@@ -723,7 +723,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "Yes. I know the yellow banana.")
+        self.assertEqual(res[1][1], "Yes. I know the yellow banana.")
 
 
     def test_question16(self):
@@ -734,7 +734,7 @@ class TestQuestionHandlerDialog(unittest.TestCase):
 
         ###
         res = self.dialog.test('myself', stmt)
-        self.assertEquals(res[1][1], "The yellow banana.")
+        self.assertEqual(res[1][1], "The yellow banana.")
 
 
 class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
@@ -776,7 +776,7 @@ class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
 
         try:
 
-            self.oro.addForAgent('ACHILLE',
+            self.oro.addForAgent(ResourcePool().get_model_mapping('ACHILLE'),
                                  ['ACHILLE rdf:type Human',
                                   'ACHILLE rdfs:label Achille',
                                   'JULIE rdf:type Human',
@@ -805,13 +805,13 @@ class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
     def test1(self):
 
         self.oro.add(['TAPE1 isIn CARDBOARD_BOX'])
-        self.oro.removeForAgent('ACHILLE', ['ACHILLE focusesOn TAPE2'])
-        self.oro.addForAgent('ACHILLE', ['ACHILLE focusesOn CARDBOARD_BOX'])
+        self.oro.removeForAgent(ResourcePool().get_model_mapping('ACHILLE'), ['ACHILLE focusesOn TAPE2'])
+        self.oro.addForAgent(ResourcePool().get_model_mapping('ACHILLE'), ['ACHILLE focusesOn CARDBOARD_BOX'])
 
         stmt = "Jido, what is in the box?"
         answer = "this box"
         ####
-        self.assertEquals(self.dialog.test('ACHILLE', stmt, answer)[1][1], "The Lords of the robots.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt, answer)[1][1], "The Lords of the robots.")
 
 
     def test2(self):
@@ -821,7 +821,7 @@ class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
 
         stmt = "Ok. And where is the other tape?"
         ####
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1], "Alright. The other tape is on the table.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1], "Alright. The other tape is on the table.")
 
     def test3(self):
         stmt = "Ok thank you."
@@ -829,7 +829,7 @@ class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
 
     def test3_2(self):
         stmt = "thank you."
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1], "You're welcome.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1], "You're welcome.")
 
 
     def test4(self):
@@ -865,12 +865,12 @@ class TestQuestionHandlerScenarioMovingToLondon(unittest.TestCase):
     def test_6(self):
 
         ###
-        self.oro.removeForAgent('ACHILLE', ['ACHILLE focusesOn CARDBOARD_BOX'])
-        self.oro.addForAgent('ACHILLE', ['ACHILLE focusesOn TAPE2'])
+        self.oro.removeForAgent(ResourcePool().get_model_mapping('ACHILLE'), ['ACHILLE focusesOn CARDBOARD_BOX'])
+        self.oro.addForAgent(ResourcePool().get_model_mapping('ACHILLE'), ['ACHILLE focusesOn TAPE2'])
         stmt = "Jido, can you reach this tape?"
         ####
         ## expected to check['myself reaches TAPE2']
-        self.assertEquals(self.dialog.test('ACHILLE', stmt)[1][1], "I don't know, if I can reach it.")
+        self.assertEqual(self.dialog.test('ACHILLE', stmt)[1][1], "I don't know, if I can reach it.")
 
 
     def test_7(self):
