@@ -13,9 +13,10 @@ from dialogs.helpers.helpers import colored_print
 
 from dialogs.dialog_exceptions import *
 from dialogs.resources_manager import ResourcePool
-from statements_builder import NominalGroupStatementBuilder, get_class_name, generate_id #for nominal group discrimination
-from discrimination import Discrimination
-from anaphora_matching import AnaphoraMatcher, recover_nominal_group_list, first_replacement
+from .statements_builder import NominalGroupStatementBuilder, get_class_name, \
+    generate_id  # for nominal group discrimination
+from .discrimination import Discrimination
+from .anaphora_matching import AnaphoraMatcher, recover_nominal_group_list, first_replacement
 from dialogs.sentence import *
 from dialogs.sentence_factory import SentenceFactory
 
@@ -39,7 +40,7 @@ class Resolver(object):
         self._current_object = None
         self.sentences_store = sentences_store
 
-    ##########################################
+    # #########################################
     #   References and anaphoric resolutions
     ##########################################
 
@@ -110,13 +111,12 @@ class Resolver(object):
         noun = ""
         try:
             noun = nominal_group.noun[0].replace('+', ' ')
-            onto_res = ResourcePool().ontology_server.lookupForAgent(current_speaker, noun)
+            onto_res = ResourcePool().ontology_server.lookupForAgent(ResourcePool().get_model_mapping(current_speaker),
+                                                                     noun)
         except IndexError:
             raise DialogError("We should not have to resolve nominal " + \
                               "groups with indefinite determiner and only adjectives")
-        except AttributeError:
-            pass
-        except KbError: # The agent does not exist in the ontology
+        except KbError:  # The agent does not exist in the ontology
             pass
 
         return get_class_name(noun, onto_res)
@@ -147,32 +147,28 @@ class Resolver(object):
                               "magenta"))
 
             if nominal_group.noun and nominal_group.noun[
-                0].lower() != 'one': # case "this + category" -> eg "this phone"
+                0].lower() != 'one':  # case "this + category" -> eg "this phone"
                 class_name = self._get_class_name_from_ontology(current_speaker, nominal_group)
                 logger.debug(colored_print("Looking for : ", "magenta") + colored_print(
-                    current_speaker + ' pointsAt ?concept, ?concept rdf:type ' + class_name, None, "magenta"))
+                    current_speaker + ' focusesOn ?concept, ?concept rdf:type ' + class_name, None, "magenta"))
                 try:
                     onto_focus = ResourcePool().ontology_server.findForAgent(
-                        current_speaker,
+                        ResourcePool().get_model_mapping(current_speaker),
                         '?concept',
-                        [current_speaker + ' pointsAt ?concept', '?concept rdf:type ' + class_name])
-                except AttributeError:
-                    pass
-                except KbError: #Agent not found in the ontology
+                        [current_speaker + ' focusesOn ?concept', '?concept rdf:type ' + class_name])
+                except KbError:  #Agent not found in the ontology
                     pass
 
-            else: # case "this" alone or "this one"
+            else:  # case "this" alone or "this one"
                 logger.debug(
-                    colored_print("Looking for : ", "magenta") + colored_print(current_speaker + ' pointsAt ?concept',
+                    colored_print("Looking for : ", "magenta") + colored_print(current_speaker + ' focusesOn ?concept',
                                                                                None, "magenta"))
                 try:
                     onto_focus = ResourcePool().ontology_server.findForAgent(
-                        current_speaker,
+                        ResourcePool().get_model_mapping(current_speaker),
                         '?concept',
-                        [current_speaker + ' pointsAt ?concept'])
-                except AttributeError:
-                    pass
-                except KbError: #Agent not found in the ontology
+                        [current_speaker + ' focusesOn ?concept'])
+                except KbError:  #Agent not found in the ontology
                     pass
 
             if onto_focus:
@@ -189,7 +185,7 @@ class Resolver(object):
             # Case of 
             #   this + noun - E.g: Take this cube:
             if nominal_group.noun and nominal_group.noun[0].lower() != 'one':
-                pass # Nothing to do appart from processing "this" as "the"
+                pass  # Nothing to do appart from processing "this" as "the"
 
             # Case of 
             #   this + one -  E.g: Take this one
@@ -200,7 +196,7 @@ class Resolver(object):
                         nominal_group, matcher,
                         current_speaker,
                         current_object)
-                except DialogError: #...no dialog history yet! or nothing found in history. Can not do any matching over past sentences
+                except DialogError:  #...no dialog history yet! or nothing found in history. Can not do any matching over past sentences
                     uie = UnsufficientInputError({'status': 'FAILURE'})
 
                     sf = SentenceFactory()
@@ -218,15 +214,14 @@ class Resolver(object):
         # Case of an existing ID in the Ontology
         onto = []
         try:
-            onto = ResourcePool().ontology_server.lookupForAgent(current_speaker, nominal_group.noun[0])
-        except AttributeError: #the ontology server is not started or doesn't know the method
-            pass
-        except KbError: #The agent does not exist in the ontology
+            onto = ResourcePool().ontology_server.lookupForAgent(ResourcePool().get_model_mapping(current_speaker),
+                                                                 nominal_group.noun[0])
+        except KbError:  #The agent does not exist in the ontology
             pass
 
         if onto:
             for c in onto:
-                if "INSTANCE" in c:
+                if "instance" in c:
                     nominal_group.id = c[0]
                     logger.debug("... \t" + nominal_group.noun[0] + " is an existing ID (" + nominal_group.id + \
                                  ") in " + current_speaker + "'s model.")
@@ -274,7 +269,7 @@ class Resolver(object):
 
             else:
                 if nominal_group._quantifier in ['SOME']:
-                # Do not deal further here with existential quantifier. It will be processed
+                    # Do not deal further here with existential quantifier. It will be processed
                     # later in noun_resolution.
                     return nominal_group
 
@@ -287,9 +282,10 @@ class Resolver(object):
                     onto_id = []
                     try:
                         # TODO: anything -> all Artifact: is that right?
-                        onto_id = ResourcePool().ontology_server.findForAgent(current_speaker, '?concept',
-                                                                              ['?concept rdf:type Artifact'])
-                    except KbError: # The agent does not exist in the ontology
+                        onto_id = ResourcePool().ontology_server.findForAgent(
+                            ResourcePool().get_model_mapping(current_speaker), '?concept',
+                            ['?concept rdf:type Artifact'])
+                    except KbError:  # The agent does not exist in the ontology
                         pass
 
                 else:
@@ -305,9 +301,10 @@ class Resolver(object):
 
                     onto_id = []
                     try:
-                        onto_id = ResourcePool().ontology_server.findForAgent(current_speaker, '?concept',
-                                                                              ['?concept rdf:type ' + class_name])
-                    except KbError: # The agent does not exist in the ontology
+                        onto_id = ResourcePool().ontology_server.findForAgent(
+                            ResourcePool().get_model_mapping(current_speaker), '?concept',
+                            ['?concept rdf:type ' + class_name])
+                    except KbError:  # The agent does not exist in the ontology
                         pass
 
                 if not onto_id:
@@ -431,7 +428,7 @@ class Resolver(object):
             The output is the ID of the nominal group
         """
 
-        if nominal_group._resolved: #already resolved: possible after asking human for more details.
+        if nominal_group._resolved:  #already resolved: possible after asking human for more details.
             return nominal_group
 
         logger.debug(str(nominal_group))
@@ -460,20 +457,18 @@ class Resolver(object):
                          '[' + colored_print(', '.join(stmtsAndVisibility), None, 'magenta') + ']')
             concepts = []
             try:
-                concepts = ResourcePool().ontology_server.findForAgent(current_speaker, '?concept', stmtsAndVisibility)
-            except AttributeError: # No ontology server
-                pass
-            except KbError: #The agent does not exist in the ontology
+                concepts = ResourcePool().ontology_server.findForAgent(
+                    ResourcePool().get_model_mapping(current_speaker), '?concept', stmtsAndVisibility)
+            except KbError:  #The agent does not exist in the ontology
                 pass
 
             if not concepts:
                 # no acceptable concepts that are visible. Look for concepts that are not visible."
                 logger.debug(colored_print("No visible concepts found. Removing the visibility constraint"))
                 try:
-                    concepts = ResourcePool().ontology_server.findForAgent(current_speaker, '?concept', stmts)
-                except AttributeError: # No ontology server
-                    pass
-                except KbError: #The agent does not exist in the ontology
+                    concepts = ResourcePool().ontology_server.findForAgent(
+                        ResourcePool().get_model_mapping(current_speaker), '?concept', stmts)
+                except KbError:  #The agent does not exist in the ontology
                     pass
 
             if concepts:
@@ -591,10 +586,8 @@ class Resolver(object):
         logger.debug(
             colored_print("\tFound '(an)other'. Looking for a different concept from dialog history.", "magenta"))
         obj_list = []
-        try:
-            obj_list = ResourcePool().ontology_server.findForAgent(current_speaker, '?concept', current_stmts)
-        except AttributeError:
-            pass
+        obj_list = ResourcePool().ontology_server.findForAgent(ResourcePool().get_model_mapping(current_speaker),
+                                                              '?concept', current_stmts)
 
         if obj_list:
             if len(obj_list) == 1:
@@ -637,7 +630,7 @@ class Resolver(object):
         return sentence
 
     def _resolve_verbs(self, verbal_group):
-        if verbal_group.resolved(): #already resolved: possible after asking human for more details.
+        if verbal_group.resolved():  #already resolved: possible after asking human for more details.
             return verbal_group
 
         resolved_verbs = []
@@ -810,27 +803,22 @@ class Resolver(object):
         #Commiting the ontology now, in case of a research on this concept on the remaining unresolved concepts of the sentence
         logger.debug(colored_print("Learning this new concept in " + current_speaker + "'s model: \n",
                                    "magenta") + '[' + colored_print(', '.join(stmts), None, 'magenta') + ']')
-        try:
-            ResourcePool().ontology_server.revise(stmts, {"method": "add", "models": [current_speaker]})
-        except AttributeError:
-            pass
+        ResourcePool().ontology_server.revise(stmts, {"method": "add", "models": [
+            ResourcePool().get_model_mapping(current_speaker)]})
 
         if current_speaker != ResourcePool().default_model:
             logger.debug(
                 colored_print("Learning this new concept in robot's model: \n", "magenta") + '[' + colored_print(
                     ', '.join(stmts), None, 'magenta') + ']')
-            try:
-                ResourcePool().ontology_server.revise(stmts,
-                                                      {"method": "add", "models": [ResourcePool().default_model]})
-            except AttributeError:
-                pass
+            ResourcePool().ontology_server.revise(stmts,
+                                                    {"method": "add", "models": [ResourcePool().default_model]})
 
         return id
 
 
 def get_last(list, nb):
     """This returns the last 'Nb' elements of the list 'list' in the reverse order"""
-    #Empty list
+    # Empty list
     if not list:
         return list
 
