@@ -25,7 +25,7 @@
     complete_relative : to complete the relative with her object 
 """
 from dialogs.resources_manager import ResourcePool
-import other_functions
+from . import other_functions
 
 
 def is_an_adj(word):
@@ -291,7 +291,7 @@ def return_det(nominal_group):
 def return_adj(nominal_group):
     """Returns adjectives of the nominal group
 
-    :param Nominal_Group nominal_group: a nominal group
+    :param NominalGroup nominal_group: a nominal group
 
     :return: a list of adjectives
     """
