@@ -27,7 +27,7 @@ class Parser(object):
     def parse(self, preprocessed_sentences, active_sentence=None):
 
         # If the user pass a simple string, preprocess it first.
-        if isinstance(preprocessed_sentences, basestring):
+        if isinstance(preprocessed_sentences, str):
             preprocessed_sentences = self.preprocess(preprocessed_sentences)
 
         #Return active_sentence if not empty, possibly send from Dialog.
