@@ -8,6 +8,7 @@ from dialogs.helpers.sentence_atoms import *
 from dialogs.helpers.printers import pprint, level_marker
 from dialogs.helpers.helpers import colored_print
 from dialogs.resources_manager import ResourcePool
+from functools import reduce
 
 
 class Sentence(object):
@@ -15,7 +16,7 @@ class Sentence(object):
     A sentence is formed from:
     data_type: the type of a sentence whether it is a question, an imperative, ...
     sn : a nominal structure typed into a Nominal_group
-    sv : a verbal structure typed into a Verbal_Group
+    sv : a verbal structure typed into a VerbalGroup
     aim : is used for retrieveing the aim of a question
     """
 
@@ -38,11 +39,11 @@ class Sentence(object):
         sv_valid = True
         if self.sn:
             sn_valid = reduce(lambda c1, c2: c1 and c2,
-                              map(lambda x: x.isvalid(), self.sn),
+                              [x.isvalid() for x in self.sn],
                               True)
         if self.sv:
             sv_valid = reduce(lambda c1, c2: c1 and c2,
-                              map(lambda x: x.isvalid(), self.sv),
+                              [x.isvalid() for x in self.sv],
                               True)
 
         return sn_valid and sv_valid
@@ -52,11 +53,11 @@ class Sentence(object):
         to concepts known by the robot.
         """
         return reduce(lambda c1, c2: c1 and c2,
-                      map(lambda x: x._resolved, self.sn),
+                      [x._resolved for x in self.sn],
                       True) \
             and \
                reduce(lambda c1, c2: c1 and c2,
-                      map(lambda x: x._resolved, self.sv),
+                      [x._resolved for x in self.sv],
                       True)
 
 
@@ -84,8 +85,8 @@ class Sentence(object):
     def flatten(self):
         return [self.data_type,
                 self.aim,
-                map(lambda x: x.flatten(), self.sn),
-                map(lambda x: x.flatten(), self.sv)]
+                [x.flatten() for x in self.sn],
+                [x.flatten() for x in self.sv]]
 
     def isaborting(self):
         #Forget it
@@ -117,7 +118,7 @@ class Sentence(object):
         self.sv[0].vrb_sub_sentence.append(sub_sentence)
 
 
-class Nominal_Group(object):
+class NominalGroup(object):
     """
     Nominal group class declaration
     det : determinant
@@ -211,15 +212,15 @@ class Nominal_Group(object):
         return [self.det,
                 self.noun,
                 self.adj,
-                map(lambda x: x.flatten(), self.noun_cmpl),
-                map(lambda x: x.flatten(), self.relative)]
+                [x.flatten() for x in self.noun_cmpl],
+                [x.flatten() for x in self.relative]]
 
 
     def adjectives_only(self):
         """This method returns True when this nominal group holds only a set of adjectives.
         E.g: the banana is yellow. The parser provides an object sentence with two nominal groups:
-        - Nominal_Group(['the'], ['banana'], [], [],[]) and adjectives_only returns False
-        - Nominal_Group([], [], ['yellow'], [],[]) and adjectives_only returns True
+        - NominalGroup(['the'], ['banana'], [], [],[]) and adjectives_only returns False
+        - NominalGroup([], [], ['yellow'], [],[]) and adjectives_only returns True
         """
         if self.adj and \
                 not self.noun and \
@@ -230,7 +231,7 @@ class Nominal_Group(object):
             return False
 
 
-class Indirect_Complement(object):
+class IndirectComplement(object):
     """
     Indirect complement class declaration
     gn : nominal group
@@ -243,7 +244,7 @@ class Indirect_Complement(object):
 
     def resolved(self):
         return reduce(lambda c1, c2: c1 and c2,
-                      map(lambda x: x._resolved, self.gn),
+                      [x._resolved for x in self.gn],
                       True)
 
     def __str__(self):
@@ -264,16 +265,16 @@ class Indirect_Complement(object):
         return self.gn \
             and \
                reduce(lambda c1, c2: c1 and c2,
-                      map(lambda x: x.isvalid(), self.gn),
+                      [x.isvalid() for x in self.gn],
                       True)
 
 
     def flatten(self):
         return [self.prep,
-                map(lambda x: x.flatten(), self.gn)]
+                [x.flatten() for x in self.gn]]
 
 
-class Verbal_Group(object):
+class VerbalGroup(object):
     """
     Verbal_group class declaration
     vrb_main: the main verb of a sentence
@@ -328,25 +329,25 @@ class Verbal_Group(object):
         """
         return (True if self.vrb_main else False) \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.isvalid(), self.d_obj), True) \
+               reduce(lambda c1, c2: c1 and c2, [x.isvalid() for x in self.d_obj], True) \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.isvalid(), self.i_cmpl), True) \
+               reduce(lambda c1, c2: c1 and c2, [x.isvalid() for x in self.i_cmpl], True) \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.isvalid(), self.sv_sec), True) \
+               reduce(lambda c1, c2: c1 and c2, [x.isvalid() for x in self.sv_sec], True) \
             and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.isvalid(), self.vrb_sub_sentence), True)
+               reduce(lambda c1, c2: c1 and c2, [x.isvalid() for x in self.vrb_sub_sentence], True)
 
 
     def resolved(self):
         return self._resolved \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x._resolved, self.d_obj), True) \
+               reduce(lambda c1, c2: c1 and c2, [x._resolved for x in self.d_obj], True) \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.resolved(), self.i_cmpl), True) \
+               reduce(lambda c1, c2: c1 and c2, [x.resolved() for x in self.i_cmpl], True) \
                    and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.resolved(), self.sv_sec), True) \
+               reduce(lambda c1, c2: c1 and c2, [x.resolved() for x in self.sv_sec], True) \
             and \
-               reduce(lambda c1, c2: c1 and c2, map(lambda x: x.resolved(), self.vrb_sub_sentence), True)
+               reduce(lambda c1, c2: c1 and c2, [x.resolved() for x in self.vrb_sub_sentence], True)
 
     def __str__(self):
         res = pprint(" ".join(self.vrb_main), VERB) + pprint(self.vrb_tense, TENSE)
@@ -371,7 +372,7 @@ class Verbal_Group(object):
             for vrb_sec_s in self.sv_sec:
                 res += '\t' + pprint(str(vrb_sec_s).replace("\n", "\n\t"), SECONDARY_VERBAL_GROUP) + "\n"
 
-        res = pprint(res, AFFIRMATIVE if self.state == Verbal_Group.affirmative else NEGATIVE)
+        res = pprint(res, AFFIRMATIVE if self.state == VerbalGroup.affirmative else NEGATIVE)
         res = pprint(res, RESOLVED) if self.resolved() else pprint(res, NOT_RESOLVED)
 
         return pprint(res, VERBAL_GROUP)
@@ -379,14 +380,14 @@ class Verbal_Group(object):
 
     def flatten(self):
         return [self.vrb_main,
-                map(lambda x: x.flatten(), self.sv_sec),
+                [x.flatten() for x in self.sv_sec],
                 self.vrb_tense,
-                map(lambda x: x.flatten(), self.d_obj),
-                map(lambda x: x.flatten(), self.i_cmpl),
+                [x.flatten() for x in self.d_obj],
+                [x.flatten() for x in self.i_cmpl],
                 self.vrb_adv,
                 self.advrb,
                 self.state,
-                map(lambda x: x.flatten(), self.vrb_sub_sentence)]
+                [x.flatten() for x in self.vrb_sub_sentence]]
 
 
 class Comparator(object):
@@ -579,7 +580,7 @@ def i_cmpl(indirect_complement):
             list_nominal_group = indirect_complement[i].gn[1:]
             indirect_complement[i].gn = [indirect_complement[i].gn[1]]
             for k in list_nominal_group:
-                indirect_complement = indirect_complement + [Indirect_Complement(indirect_complement[i].prep, [k])]
+                indirect_complement = indirect_complement + [IndirectComplement(indirect_complement[i].prep, [k])]
         i += 1
     return indirect_complement
 
@@ -593,10 +594,10 @@ def nominal_group_remerge(utterance, flag, nominal_group_structure):
     for i in utterance:
         if i.data_type == IMPERATIVE:
             i.data_type = STATEMENT
-            i.sn = [Nominal_Group(['the'], i.sv[0].vrb_main, [], [], [])]
+            i.sn = [NominalGroup(['the'], i.sv[0].vrb_main, [], [], [])]
 
         if i.data_type == STATEMENT or i.data_type.startswith(SUBSENTENCE):
-            if not i.sv or i.sv[0].state == Verbal_Group.affirmative:
+            if not i.sv or i.sv[0].state == VerbalGroup.affirmative:
 
                 #We can have just the subject
                 if not i.sv:
@@ -613,7 +614,7 @@ def nominal_group_remerge(utterance, flag, nominal_group_structure):
                     for v in i.sv:
                         nominal_group_structure = process_verbal_group_part(v, nominal_group_structure, flag)
 
-            elif i.sv[0].state == Verbal_Group.negative:
+            elif i.sv[0].state == VerbalGroup.negative:
                 #For all other sentences flag will be FAILURE
                 flag = 'FAILURE'
 
